#
# spec file for package caja-dropbox
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _version 1.28

Name:           caja-dropbox
Version:        1.28.0
Release:        1.4
Summary:        Dropbox client integrated into Caja
License:        GPL-3.0-or-later
URL:            https://mate-desktop.org/
Group:          Productivity/File utilities
Source:         https://pub.mate-desktop.org/releases/%{_version}/%{name}-%{version}.tar.xz
# PATCH-FIX-OPENSUSE caja-dropbox_no-dropbox-bin.patch sor.alexei@meowr.ru -- Strip dropbox binary installation.
Patch0:         caja-dropbox_no-dropbox-bin.patch
BuildRequires:  hicolor-icon-theme
BuildRequires:  mate-common >= %{_version}
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(libcaja-extension) >= %{_version}
Recommends:     %{name}-lang

%description
Dropbox is a proprietary service that lets one bring photos,
documents, and videos anywhere and share them easily.

This package integrates Dropbox seamlessly into Caja.

%package -n caja-extension-dropbox
Summary:        Dropbox client integrated into Caja
Requires:       caja >= %{_version}
Requires:       dropbox
# caja-dropbox was last used in openSUSE Leap 42.1.
Provides:       caja-dropbox = %{version}
Obsoletes:      caja-dropbox < %{version}

%description -n caja-extension-dropbox
Dropbox is a proprietary service that lets one bring photos,
documents, and videos anywhere and share them easily.

This package integrates Dropbox seamlessly into Caja.

%lang_package

%prep
%autosetup -p1

%build
NOCONFIGURE=1 mate-autogen
%configure \
  --disable-static
%make_build

%install
%make_install

%find_lang %{name}

%files -n caja-extension-dropbox
%license COPYING
%doc AUTHORS NEWS README
%{_libdir}/caja/extensions-2.0/libcaja-dropbox.*

%files lang -f %{name}.lang

%changelog
* Mon Mar 25 2024 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.28.0
  * Update translations
  * Fix -Wmissing-field-initializers
* Sat Aug 14 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.26.0
  * Update translations
* Wed Feb 26 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.24.0:
  * Update copyright to 2020.
- Drop support for old openSUSE versions.
* Thu Jul 18 2019 Jonathan Brielmaier <jbrielmaier@suse.de>
- Update to version 1.23.0:
  * Change url project's website
  * Use CAJA_EXTENSION_DIR_SYS to save and show system caja extension dir
  * show full path of caja-extension-dir
- remove patch:
  * caja-dropbox_glib-2.48.patch: we don't support gtk3.20 anymore
- build require glib >= 2.50
* Sun May 12 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.22.1:
  * Use CAJA_EXTENSION_DIR_SYS to save and show system
    caja extension dir.
  * Show full path of caja-extension-dir.
* Tue Mar  5 2019 sor.alexei@meowr.ru
- Update to version 1.22.0:
  * Python 3 update for dropbox-cli.
  * Add Keywords entry to desktop file.
  * Use cross-compilation-safe pkg-config macro.
  * Remove deprecated glib2.0 API calls.
  * Use GIR bindings instead of pygtk.
  * Fix UnicodeWarning when exclude command is used with non-latin
    args.
  * Update to redesigned icons.
  * small caja-dropbox.in fixes.
  * Add a new "dropbox update" command.
  * Unlink files that are going to be replaced by the unpack.
  * Validate that Dropbox runs after downloading it.
  * Use python-gpg instead of python-gpgme.
  * Explicitly load using python2 interpreter.
  * Refer to .dropbox-dist in only one place.
  * Fixed 'exclude command raise UnicodeDecodeError'.
  * Avoid reading or writing invalid memory addresses.
  * Display link url on status.
  * Update dropbox.py with shmodel, proxy, and throttle features.
  * Fix distcheck about caja_extension_dir.
  * Use only Python 3 during the build to complete the migration.
  * Migrate from python2 to python3 of rst2man.py.
  * Remove more -u modifier for dropbox-cli.
- Rebase caja-dropbox_no-dropbox-bin.patch.
* Fri Mar  9 2018 sor.alexei@meowr.ru
- Update to version 1.20.0:
  * Require GLib 2.50.
- Add caja-dropbox_glib-2.48.patch -- Restore GLib 2.48 support.
* Tue Mar 14 2017 sor.alexei@meowr.ru
- Update to version 1.18.0:
  * NEWS: Use consistent, project wide, markdown-like formatting to
    make generating release announcements easier.
  * Build: require libcaja-extension 1.17.1 and GLib 2.36.
* Tue Sep 20 2016 sor.alexei@meowr.ru
- Update to version 1.16.0:
  * Some code cleanups.
- Extend caja-dropbox_no-dropbox-bin.patch to dependency check.
* Sat Apr  9 2016 sor.alexei@meowr.ru
- Update to version 1.14.0:
  * Fix Changelog generation.
- Rebase caja-dropbox_no-dropbox-bin.patch.
* Thu Nov  5 2015 sor.alexei@meowr.ru
- Update to 1.12.0:
  * Adjust the default caja extensions dir.
  * Include autogen.sh in tarball.
- Rename package to caja-extension-dropbox.
- Drop dropbox binary from package and rely on dropbox package.
- Add caja-dropbox_no-dropbox-bin.patch.
* Mon Oct 12 2015 ronisbr@gmail.com
- Initial version.
